@@ -13,11 +13,11 @@ use vars qw($VERSION);
 
 =head1 VERSION
 
-This documentation explains the use of ExtUtils::nvcc version 0.02.
+This documentation explains the use of ExtUtils::nvcc version 0.03.
 
 =cut
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 # For errors, of course:
 use Carp qw(croak);
@@ -320,6 +320,7 @@ ExtUtils::nvcc itself, don't worry about this function.
 # Throws		: if a bade mode or an invalid option is provided
 # Comments		: For example, an output of this function with no args could be
 #				:    perl -MExtUtils::nvcc::Backend -e"ExtUtils::nvcc::Backend::linker" --
+#				: This also checks for current use of blib and adds it if found
 # See also		: verbosity, Inline, EUMM, MB, %args_for
 
 sub build_args {
@@ -327,10 +328,18 @@ sub build_args {
 	croak("Bad mode; must be either 'compiler' or 'linker'")
 		unless $mode eq 'compiler' or $mode eq 'linker';
 	
+	# Inject -Mblib if this script was invoked with blib:
+	my $args = $^X;
+	if (grep /blib/, @INC) {
+		use Cwd;
+		$args .= ' -Mblib="' . getcwd . '"';
+	}
+	
+
 	# Go through and build the argument list, checking the arguments along the
 	# way. If there are bad arguments, collect a full list and croak them all.
 
-	my $args = qq{$^X -MExtUtils::nvcc::Backend -e"};
+	$args .= qq{ -MExtUtils::nvcc::Backend -e"};
 	my @bad_args;
 	foreach (@_) {
 		if (exists $arg_for{$_}) {
@@ -346,6 +355,35 @@ sub build_args {
 
 1;
 
+=head1 WINDOWS ISSUES
+
+Windows usage presents a couple of difficulties, as described in this section.
+
+=head2 Visual Studio Only
+
+Unfortunately, nVidia's compiler wrapper (nvcc) only supports the use of cl.exe
+on Windows. This means that Cygwin and Strawberry Perl users are out of luck for
+using ExtUtils::nvcc. I attempted to install Visual Studio alongside Strawberry
+Perl, but the Perl toolchain passes along the gcc flags, which cl.exe does not
+like. There may be a way to fiddle with the configuration a bit, but I wouldn't
+hold my breath.
+
+An alternative may be to create a drop-in cl.exe replacement which parses the
+arguments for cl.exe and invokes gcc. If that's not reverse-engineering
+reverse-engineered, I don't know what is.
+
+=head2 Visual Studio Command Prompt
+
+When you install Visual Studio (as of Visual Studio 2010), you will get a Start
+Menu entry for Visual Studio Command Prompt. You should run your build processes
+(i.e. cpan) from one of these command prompts. Among other things, this command
+prompt sets all of the necessary environment variables to ensure that the
+compiler can be found, and that the compiler can find all the necessary
+libraries. This may or may not be necessary for using nvcc directly, but it is
+certainly is necessary for the rest of the Perl toolchain to find cl.exe and
+friends.
+
+
 =head1 DIAGNOSTICS
 
 ExtUtils::nvcc could croak for a number of reasons. To keep things concise, I
@@ -429,7 +467,11 @@ This toolchain requires that you have the following pieces:
 You must have nVidia's CUDA toolkit in order to compile CUDA code. This module
 ultimately calls nvcc to perform the compilation; it cannot compile your CUDA
 code itself. Furthermore, nvcc requires a C++ compiler, so you'll need to be
-sure you have one of those.
+sure you have one of those. The CUDA toolkit is only available for a handful of
+systems, and this module does not support building CUDA-capable modules for
+other systems. For example, the latest version of Ubuntu or Fedora may not be
+supported, and as of this time of writing Gentoo and Arch Linux (and many
+others) have no support at all.
 
 =item A Perl development environment
 
@@ -439,32 +481,51 @@ backend.) If you are in an environment in which you do not have these tools,
 you will be able to use L<ExtUtils::nvcc::Backend>, but you'll have a hard time
 tying anything into Perl.
 
+=item gcc (Linux) or Visual Studio (Windows)
+
+The nvcc compiler only supports gcc on Linux, and cl.exe on Windows. You cannot
+specify an alternative compiler.
+
 =back
 
-=head1 BUGS AND LIMITATIONS
-
-The giant, huge, fat, glaring bug with ExtUtils::nvcc is that it creates code
-which segfaults at the very end of the program. There is deep magic, almost
-certainly involving a double-free, which I have yet to figure out. Any help for
-this would be much appreciated.
-
-The second major problem is that the Backend has a very ad-hoc parsing scheme
-that is not tested at the moment. It would be better, I think, to query nvcc at
-runtime for arguments that it accepts so that there could never be a version
-skew for the arguments that the Backend parses and the arguments that nvcc
-accepts.
-
-I believe C<ExtUtils::nvcc> will operate on Windows machines under Cygwin and
-under Strawberry Perl, since they use gcc. Furthermore, I believe that 
-C<ExtUtils::nvcc> does in fact work with Microsoft's compiler as well, but I do
-not have a Windows machine or the Microsoft toolchain so I cannot develop or
-test for that system. If you are a developer with an interest in ensuring that
-L<ExtUtils::nvcc::Backend> works with Microsoft's compiler, I welcome your
-contributions!
+=head1 BUGS, LIMITATIONS
 
 The code for ExtUtils::nvcc is hosted at github, but please file bugs at
 L<https://rt.cpan.org/Public/Bug/Report.html?Queue=ExtUtils-nvcc>.
 
+A major maintainability problem is that the Backend has a very ad-hoc parsing
+scheme that is not systematically tested at the moment. It would be better, I
+think, to query nvcc at runtime for arguments that it accepts so that there
+could never be a version skew for the arguments that the Backend parses and the
+arguments that nvcc accepts. However, nvcc does not have an easily parsed
+representation of its arguments, so this is probably equally troublesome.
+
+For Windows users, a major issue is that nvcc only works with Microsoft's
+compiler, cl.exe, on Windows machines. As such, C<ExtUtils::nvcc> will not
+operate correctly under Cygwin or Strawberry Perl. I would like to remedy
+this situation. Please let me know if you find a work-around for Strawberry
+Perl or Cygwin.
+
+Furthermore, C<ExtUtils::nvcc> doesn't even work with Windows at the moment.
+This module was developed on Ubuntu and I have only dabbled with the Windows
+build system. It is giving trouble, and any help would be much appreciated.
+
+=head1 TESTING
+
+In the few months that ExtUtils::nvcc has been quietly sitting on CPAN, it
+has received zero test reports. That's because there isn't a single automated
+tester that has nvcc installed. If you try to install this module, please
+report your success or failure at cpantesters. The process is a bit involved,
+but your test reports will help to turn this piddly little thing into a
+useful tool! You can read more here: L<http://wiki.cpantesters.org/wiki/QuickStart>.
+
+=head1 TODO
+
+The only major missing piece at this time is a true test of the build
+process using ExtUtils::MakeMake and/or Module::Build. I would like to
+add tests of these to the test suite, but it'll take some thought to
+figure out how to invoke the build system from inside the test suite.
+
 =head1 AUTHOR
 
 I have obfuscated my email address. Simply remove the portion that would not
@@ -476,16 +537,16 @@ David Mertens <dcmertens.perl.csharp@gmail.com>
 
 The source code for this project is on github at L<github.com/run4flat/perl_nvcc>.
 
-This is intended to be part of the toolchain to enable L<CUDA>. A Perl module
-for CUDA does not yet exist, but (hopefully) this will be used for it when that
-happens.
+This is intended to be part of the toolchain to enable L<CUDA>. A minimalistic
+Perl module for CUDA is in the works and can be found at
+L<github.com/run4flat/perl-CUDA-Minimal>.
 
 You can read more about CUDA at nVidia's website:
 L<http://www.nvidia.com/object/cuda_home_new.html>
 
 An alternative to embedding CUDA in C or XS is L<KappaCUDA>.
 
-Other imporant and related toolchain modules include L<Inline::C>,
+Other important and related toolchain modules include L<Inline::C>,
 L<Module::Build>, L<ExtUtils::MakeMaker>
 
 =head1 LICENSE AND COPYRIGHT
